# OpenTimelineIO

<picture>
  <source media="(prefers-color-scheme: dark)" srcset="https://raw.githubusercontent.com/AcademySoftwareFoundation/OpenTimelineIO/main/docs/_static/OpenTimelineIO@3xLight.png">
  <source media="(prefers-color-scheme: light)" srcset="https://raw.githubusercontent.com/AcademySoftwareFoundation/OpenTimelineIO/main/docs/_static/OpenTimelineIO@3xDark.png">
  <img alt="OpenTimelineIO Logo" src="./images/OpenTimelineIO@3xDark.png">
</picture>

[OpenTimelineIO](https://opentimeline.io) is an interchange format and API for
editorial cut information.

This package is a convenience includes both OpenTimelineIO and a set of plugins
maintained by the OpenTimelineIO community that are commonly used with the
library.

## Support

The included plugins are part of the OpenTimelineIO project but may be supported
differently than the OpenTimelineIO core.

This may include:

- Repos primarily maintained by community members with OpenTimelineIO core team members only providing guidance
- Repos that aren't actively maintained

Please consult READMEs in individual subproject repos to learn more about their
maintainance and support.

Links
-----

* Main web site: http://opentimeline.io/
* Documentation: https://opentimelineio.readthedocs.io/
* Main Project GitHub: https://github.com/AcademySoftwareFoundation/OpenTimelineIO
* [Discussion group](https://lists.aswf.io/g/otio-discussion)
* [Slack channel](https://academysoftwarefdn.slack.com/messages/CMQ9J4BQC)
  * To join, create an account here first: https://slack.aswf.io/
* [Presentations](https://github.com/AcademySoftwareFoundation/OpenTimelineIO/wiki/Presentations)
